@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright (c) 2014  Kontron Europe GmbH
 #
 # This library is free software; you can redistribute it and/or
@@ -12,36 +13,37 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
 from __future__ import absolute_import
-from builtins import object
 
 import time
-import sys
+import ast
 
 from . import bmc
 from . import chassis
 from . import event
 from . import fru
-#import functools
 from . import hpm
 from . import lan
+from . import messaging
 from . import picmg
 from . import sdr
 from . import sel
 from . import sensor
 from . import msgs
 
-from .errors import TimeoutError, CompletionCodeError
+from .errors import IpmiTimeoutError, CompletionCodeError, RetryError
 from .msgs.registry import create_request_by_name
-from .utils import check_completion_code
+from .session import Session
+from .utils import check_completion_code, is_string
 
 try:
     from version import __version__
 except ImportError:
     __version__ = 'dev'
 
+
 def create_connection(interface):
     session = Session()
     session.interface = interface
@@ -51,6 +53,7 @@ def create_connection(interface):
     ipmi.requester = NullRequester()
     return ipmi
 
+
 class Requester(object):
     '''The Requester class represents an IPMI device which initiates a
     request/response message exchange.
@@ -59,6 +62,7 @@ class Requester(object):
     def __init__(self, ipmb_address):
         self.ipmb_address = ipmb_address
 
+
 class NullRequester(object):
     '''The NullRequester is used for interfaces which doesn't require a
     valid requester.
@@ -69,91 +73,95 @@ class NullRequester(object):
         raise AssertionError('NullRequester does not provide an IPMB address')
 
 
+class Routing(object):
+    """The Target class represents an IPMI target."""
+    def __init__(self, rq_sa, rs_sa, channel):
+        self.rq_sa = rq_sa
+        self.rs_sa = rs_sa
+        self.channel = channel
+
+    def __str__(self):
+        s = 'Routing: Rq: %s Rs: %s Ch: %s' \
+                % (self.rq_sa, self.rs_sa, self.channel)
+        return s
+
+
 class Target(object):
-    def __init__(self, ipmb_address, routing=None):
+    '''The Target class represents an IPMI target.'''
+    routing = None
+    ipmb_address = None
+
+    def __init__(self, ipmb_address=None, routing=None):
         """
         `ipmb_address` is the IPMB target address
         `routing` is the bridging information used to build send message
         commands.
         """
-        self.ipmb_address = ipmb_address
+
+        if ipmb_address:
+            self.ipmb_address = ipmb_address
+
         if routing:
             self.set_routing(routing)
 
-    '''The Target class represents an IPMI target.'''
-    class Routing(object):
-        def __init__(self, address, bridge_channel):
-            self.address = address
-            self.bridge_channel = bridge_channel
+    def set_routing_information(self, routing):
+        self.set_routing(routing)
 
-
-    def set_routing_information(self, rinfo):
-        self.set_routing(rinfo)
-
-    def set_routing(self, rinfo):
+    def set_routing(self, routing):
         """Set the path over which a target is reachable.
 
         The path is given as a list of tuples in the form (address,
         bridge_channel).
+
+        Example #1: access to an ATCA blade in a chassis
+              slave = 0x81, target = 0x82
+              routing = [(0x81,0x20,0),(0x20,0x82,None)]
+
+        Example #2: access to an AMC in a uTCA chassis
+              slave = 0x81, target = 0x72
+              routing = [(0x81,0x20,0),(0x20,0x82,7),(0x20,0x72,None)]
+
+
+                         uTCA - MCH                        AMC
+                       .-------------------.             .--------.
+                       |       .-----------|             |        |
+                       | ShMC  | CM        |             | MMC    |
+            channel=0  |       |           |  channel=7  |        |
+        81 ------------| 0x20  |0x82  0x20 |-------------| 0x72   |
+                       |       |           |             |        |
+                       |       |           |             |        |
+                       |       `-----------|             |        |
+                       `-------------------´             `--------´
+          `------------´     `---´        `---------------´
+
+        Example #3: access to an AMC in a ATCA AMC carrier
+
+        slave = 0x81, target = 0x72
+        routing = [(0x81,0x20,0),(0x20,0x8e,7),(0x20,0x80,None)]
+
         """
+        if is_string(routing):
+            # if type(routing) in [unicode, str]:
+            routing = ast.literal_eval(routing)
+        self.routing = [Routing(*route) for route in routing]
 
-        self.routing = [ self.Routing(*r) for r in rinfo ]
+    def __str__(self):
+        string = 'Target: IPMB: 0x%02x\n' % self.ipmb_address
+        if self.routing:
+            for route in self.routing:
+                string += ' %s\n' % route
+        return string
 
 
-class Session(object):
-    AUTH_TYPE_NONE        = 0x00
-    AUTH_TYPE_MD2         = 0x01
-    AUTH_TYPE_MD5         = 0x02
-    AUTH_TYPE_PASSWORD    = 0x04
-    AUTH_TYPE_OEM         = 0x05
-
-    def __init__(self):
-        self.set_auth_type(self.AUTH_TYPE_NONE)
-        self.established = False
-
-    def _get_interface(self):
-        try:
-            return self._interface
-        except AttributeError:
-            raise RuntimeError('No interface has been set')
-
-    def _set_interface(self, interface):
-        self._interface = interface
-
-    def set_session_type_rmcp(self, host, port=623):
-        self._rmcp_host = host
-        self._rmcp_port = port
-
-    def set_session_type_serial(self, port, baudrate):
-        self._serial_port = port
-        self._serial_baudrate = baudrate
-
-    def set_auth_type(self, auth_type):
-        self.auth_type = auth_type
-
-    def set_auth_type_user(self, username, password):
-        self.set_auth_type(self.AUTH_TYPE_PASSWORD)
-        self._auth_username = username
-        self._auth_password = password
-
-    def establish(self):
-        if hasattr(self.interface, 'establish_session'):
-            self.interface.establish_session(self)
-
-    def close(self):
-        if hasattr(self.interface, 'close_session'):
-            self.interface.close_session(self)
-
-    def rmcp_ping(self):
-        if hasattr(self.interface, 'rmcp_ping'):
-            self.interface.rmcp_ping()
-
-    interface = property(_get_interface, _set_interface)
-
 class Ipmi(bmc.Bmc, chassis.Chassis, fru.Fru, picmg.Picmg, hpm.Hpm,
-        sdr.Sdr, sensor.Sensor, event.Event, sel.Sel, lan.Lan):
+           sdr.Sdr, sensor.Sensor, event.Event, sel.Sel, lan.Lan,
+           messaging.Messaging):
 
     def __init__(self):
+        self._interface = None
+        self._session = None
+        self._target = None
+
         for base in Ipmi.__bases__:
             base.__init__(self)
 
@@ -165,41 +173,50 @@ class Ipmi(bmc.Bmc, chassis.Chassis, fru.Fru, picmg.Picmg, hpm.Hpm,
         while time.time() < start_time + (timeout):
             try:
                 self.is_ipmc_accessible()
-            except TimeoutError:
+            except IpmiTimeoutError:
                 time.sleep(interval)
 
         self.is_ipmc_accessible()
 
-    def send_message(self, req):
+    def send_message(self, req, retry=3):
         req.target = self.target
         req.requester = self.requester
+        rsp = None
 
-        retry = 3
-        while True:
+        while retry > 0:
             retry -= 1
             try:
                 rsp = self.interface.send_and_receive(req)
                 break
             except CompletionCodeError as e:
                 if e.cc == msgs.constants.CC_NODE_BUSY:
-                    retry -= 1
                     continue
+        else:
+            raise RetryError()
 
         return rsp
 
     def send_message_with_name(self, name, *args, **kwargs):
         req = create_request_by_name(name)
 
-        for k, v in kwargs.items():
-            setattr(req, k, v)
+        for key, value in kwargs.items():
+            setattr(req, key, value)
 
         rsp = self.send_message(req)
         check_completion_code(rsp.completion_code)
         return rsp
 
     def raw_command(self, lun, netfn, raw_bytes):
+        """Send the raw command data and return the raw response.
+
+        lun: the logical unit number
+        netfn: the network function
+        raw_bytes: the raw message as bytestring
+
+        Returns the response as bytestring.
+        """
         return self.interface.send_and_receive_raw(self.target, lun, netfn,
-                raw_bytes)
+                                                   raw_bytes)
 
     def _get_interface(self):
         try:
