@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 # Copyright (c) 2014  Kontron Europe GmbH
 #
 # This library is free software; you can redistribute it and/or
@@ -12,27 +13,25 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
-import constants
+from . import constants
 from . import register_message_class
 from . import Message
 from . import UnsignedInt
-from . import UnsignedIntMask
-from . import Timestamp
 from . import Bitfield
 from . import CompletionCode
-from . import Conditional
 from . import Optional
 from . import RemainingBytes
-from picmg import PicmgIdentifier
+from .picmg import PicmgIdentifier
+
 
 @register_message_class
 class GetTargetUpgradeCapabilitiesReq(Message):
     __cmdid__ = constants.CMDID_HPM_GET_TARGET_UPGRADE_CAPABILITIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -41,26 +40,24 @@ class GetTargetUpgradeCapabilitiesRsp(Message):
     __cmdid__ = constants.CMDID_HPM_GET_TARGET_UPGRADE_CAPABILITIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('hpm_1_version', 1),
-            Bitfield('capabilities', 1,
-                Bitfield.Bit('firmware_upgrade_undesirable', 1),
-                Bitfield.Bit('automatic_rollback_overriden', 1),
-                Bitfield.Bit('ipmc_degraded_during_upgrade', 1),
-                Bitfield.Bit('deferred_activation', 1),
-                Bitfield.Bit('services_affected_by_upgrade', 1),
-                Bitfield.Bit('manual_rollback', 1),
-                Bitfield.Bit('automatic_rollback', 1),
-                Bitfield.Bit('selftest', 1),
-            ),
-            Bitfield('timeout', 4,
-                Bitfield.Bit('upgrade', 8),
-                Bitfield.Bit('selftest', 8),
-                Bitfield.Bit('rollback', 8),
-                Bitfield.Bit('inaccessibility', 8),
-            ),
-            UnsignedInt('component_present', 1),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('hpm_1_version', 1),
+        Bitfield('capabilities', 1,
+                 Bitfield.Bit('firmware_upgrade_undesirable', 1),
+                 Bitfield.Bit('automatic_rollback_overriden', 1),
+                 Bitfield.Bit('ipmc_degraded_during_upgrade', 1),
+                 Bitfield.Bit('deferred_activation', 1),
+                 Bitfield.Bit('services_affected_by_upgrade', 1),
+                 Bitfield.Bit('manual_rollback', 1),
+                 Bitfield.Bit('automatic_rollback', 1),
+                 Bitfield.Bit('selftest', 1),),
+        Bitfield('timeout', 4,
+                 Bitfield.Bit('upgrade', 8),
+                 Bitfield.Bit('selftest', 8),
+                 Bitfield.Bit('rollback', 8),
+                 Bitfield.Bit('inaccessibility', 8),),
+        UnsignedInt('component_present', 1),
     )
 
 
@@ -69,9 +66,9 @@ class GetComponentPropertiesReq(Message):
     __cmdid__ = constants.CMDID_HPM_GET_COMPONENT_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('id', 1),
-            UnsignedInt('selector', 1),
+        PicmgIdentifier(),
+        UnsignedInt('id', 1),
+        UnsignedInt('selector', 1),
     )
 
 
@@ -80,9 +77,9 @@ class GetComponentPropertiesRsp(Message):
     __cmdid__ = constants.CMDID_HPM_GET_COMPONENT_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            RemainingBytes('data'),
+        CompletionCode(),
+        PicmgIdentifier(),
+        RemainingBytes('data'),
     )
 
 
@@ -91,7 +88,7 @@ class AbortFirmwareUpgradeReq(Message):
     __cmdid__ = constants.CMDID_HPM_ABORT_FIRMWARE_UPGRADE
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -100,8 +97,8 @@ class AbortFirmwareUpgradeRsp(Message):
     __cmdid__ = constants.CMDID_HPM_ABORT_FIRMWARE_UPGRADE
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -110,9 +107,9 @@ class InitiateUpgradeActionReq(Message):
     __cmdid__ = constants.CMDID_HPM_INITIATE_UPGRADE_ACTION
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('components', 1),
-            UnsignedInt('action', 1),
+        PicmgIdentifier(),
+        UnsignedInt('components', 1),
+        UnsignedInt('action', 1),
     )
 
 
@@ -121,8 +118,8 @@ class InitiateUpgradeActionRsp(Message):
     __cmdid__ = constants.CMDID_HPM_INITIATE_UPGRADE_ACTION
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -131,9 +128,9 @@ class UploadFirmwareBlockReq(Message):
     __cmdid__ = constants.CMDID_HPM_UPLOAD_FIRMWARE_BLOCK
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('number', 1),
-            RemainingBytes('data'),
+        PicmgIdentifier(),
+        UnsignedInt('number', 1),
+        RemainingBytes('data'),
     )
 
 
@@ -142,10 +139,10 @@ class UploadFirmwareBlockRsp(Message):
     __cmdid__ = constants.CMDID_HPM_UPLOAD_FIRMWARE_BLOCK
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Optional(UnsignedInt('section_offset', 4)),
-            Optional(UnsignedInt('section_length', 4)),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Optional(UnsignedInt('section_offset', 4)),
+        Optional(UnsignedInt('section_length', 4)),
     )
 
 
@@ -154,9 +151,9 @@ class FinishFirmwareUploadReq(Message):
     __cmdid__ = constants.CMDID_HPM_FINISH_FIRMWARE_UPLOAD
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('component_id', 1),
-            UnsignedInt('image_length', 4),
+        PicmgIdentifier(),
+        UnsignedInt('component_id', 1),
+        UnsignedInt('image_length', 4),
     )
 
 
@@ -165,8 +162,8 @@ class FinishFirmwareUploadRsp(Message):
     __cmdid__ = constants.CMDID_HPM_FINISH_FIRMWARE_UPLOAD
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -175,7 +172,7 @@ class GetUpgradeStatusReq(Message):
     __cmdid__ = constants.CMDID_HPM_GET_UPGRADE_STATUS
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -184,11 +181,11 @@ class GetUpgradeStatusRsp(Message):
     __cmdid__ = constants.CMDID_HPM_GET_UPGRADE_STATUS
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('command_in_progress', 1),
-            UnsignedInt('last_completion_code', 1),
-            Optional(UnsignedInt('completion_estimate', 1)),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('command_in_progress', 1),
+        UnsignedInt('last_completion_code', 1),
+        Optional(UnsignedInt('completion_estimate', 1)),
     )
 
 
@@ -197,8 +194,8 @@ class ActivateFirmwareReq(Message):
     __cmdid__ = constants.CMDID_HPM_ACTIVATE_FIRMWARE
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            Optional(UnsignedInt('rollback_override_policy', 1)),
+        PicmgIdentifier(),
+        Optional(UnsignedInt('rollback_override_policy', 1)),
     )
 
 
@@ -207,8 +204,8 @@ class ActivateFirmwareRsp(Message):
     __cmdid__ = constants.CMDID_HPM_ACTIVATE_FIRMWARE
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -217,7 +214,7 @@ class QuerySelftestResultsReq(Message):
     __cmdid__ = constants.CMDID_HPM_QUERY_SELFTEST_RESULTS
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -226,10 +223,10 @@ class QuerySelftestResultsRsp(Message):
     __cmdid__ = constants.CMDID_HPM_QUERY_SELFTEST_RESULTS
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('selftest_result_1', 1),
-            UnsignedInt('selftest_result_2', 1),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('selftest_result_1', 1),
+        UnsignedInt('selftest_result_2', 1),
     )
 
 
@@ -238,7 +235,7 @@ class QueryRollbackStatusReq(Message):
     __cmdid__ = constants.CMDID_HPM_QUERY_ROLLBACK_STATUS
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -247,10 +244,10 @@ class QueryRollbackStatusRsp(Message):
     __cmdid__ = constants.CMDID_HPM_QUERY_ROLLBACK_STATUS
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('rollback_status', 1),
-            Optional(UnsignedInt('completion_estimate', 1)),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('rollback_status', 1),
+        Optional(UnsignedInt('completion_estimate', 1)),
     )
 
 
@@ -259,7 +256,7 @@ class InitiateManualRollbackReq(Message):
     __cmdid__ = constants.CMDID_HPM_INITIATE_MANUAL_ROLLBACK
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -268,6 +265,6 @@ class InitiateManualRollbackRsp(Message):
     __cmdid__ = constants.CMDID_HPM_INITIATE_MANUAL_ROLLBACK
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
