@@ -12,17 +12,15 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
 from __future__ import absolute_import
-from builtins import range
 
 from . import constants
 from . import register_message_class
 from . import Message
 from . import UnsignedInt
 from . import UnsignedIntMask
-from . import Timestamp
 from . import Bitfield
 from . import CompletionCode
 from . import Conditional
@@ -95,9 +93,10 @@ LED_STATE_LOCAL_CONTROL = 0
 LED_STATE_OVERRIDE = 1
 LED_STATE_LAMP_TEST = 2
 
+
 class PicmgIdentifier(UnsignedInt):
     def __init__(self, name='picmg_identifier'):
-        super(self.__class__, self).__init__(name, 1, PICMG_IDENTIFIER)
+        super(PicmgIdentifier, self).__init__(name, 1, PICMG_IDENTIFIER)
 
 
 @register_message_class
@@ -105,7 +104,7 @@ class GetPicmgPropertiesReq(Message):
     __cmdid__ = constants.CMDID_GET_PICMG_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -114,11 +113,11 @@ class GetPicmgPropertiesRsp(Message):
     __cmdid__ = constants.CMDID_GET_PICMG_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('extension_version', 1),
-            UnsignedInt('max_fru_device_id', 1),
-            UnsignedInt('fru_device_id', 1),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('extension_version', 1),
+        UnsignedInt('max_fru_device_id', 1),
+        UnsignedInt('fru_device_id', 1),
     )
 
 
@@ -127,8 +126,8 @@ class GetAddressInfoReq(Message):
     __cmdid__ = constants.CMDID_GET_ADDRESS_INFO
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
 
@@ -137,23 +136,23 @@ class GetAddressInfoRsp(Message):
     __cmdid__ = constants.CMDID_GET_ADDRESS_INFO
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('hardware_address', 1),
-            UnsignedInt('ipmb_0_address', 1),
-            UnsignedInt('ipmb_1_address', 1),
-            Optional(
-                UnsignedInt('fru_id', 1),
-            ),
-            Optional(
-                UnsignedInt('site_id', 1),
-            ),
-            Optional(
-                UnsignedInt('site_type', 1),
-            ),
-            Optional(
-                UnsignedInt('carrier_number', 1),
-            ),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('hardware_address', 1),
+        UnsignedInt('ipmb_0_address', 1),
+        UnsignedInt('ipmb_1_address', 1),
+        Optional(
+            UnsignedInt('fru_id', 1),
+        ),
+        Optional(
+            UnsignedInt('site_id', 1),
+        ),
+        Optional(
+            UnsignedInt('site_type', 1),
+        ),
+        Optional(
+            UnsignedInt('carrier_number', 1),
+        ),
     )
 
 
@@ -162,7 +161,7 @@ class GetShelfAddressInfoReq(Message):
     __cmdid__ = constants.CMDID_GET_SHELF_ADDRESS_INFO
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
+        PicmgIdentifier(),
     )
 
 
@@ -171,9 +170,9 @@ class GetShelfAddressInfoRsp(Message):
     __cmdid__ = constants.CMDID_GET_SHELF_ADDRESS_INFO
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            RemainingBytes('shelf_address'),
+        CompletionCode(),
+        PicmgIdentifier(),
+        RemainingBytes('shelf_address'),
     )
 
 
@@ -182,9 +181,9 @@ class FruControlReq(Message):
     __cmdid__ = constants.CMDID_FRU_CONTROL
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('option', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('option', 1),
     )
 
 
@@ -193,9 +192,9 @@ class FruControlRsp(Message):
     __cmdid__ = constants.CMDID_FRU_CONTROL
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            RemainingBytes('rsp_data'),
+        CompletionCode(),
+        PicmgIdentifier(),
+        RemainingBytes('rsp_data'),
     )
 
 
@@ -204,8 +203,8 @@ class GetFruControlCapabilitiesReq(Message):
     __cmdid__ = constants.CMDID_FRU_CONTROL_CAPABILITIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
 
@@ -214,15 +213,14 @@ class GetFruControlCapabilitiesRsp(Message):
     __cmdid__ = constants.CMDID_FRU_CONTROL_CAPABILITIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('capabilities', 1,
-                Bitfield.ReservedBit(1),
-                Bitfield.Bit('warm_reset', 1),
-                Bitfield.Bit('graceful_reboot', 1),
-                Bitfield.Bit('diagnostic_interrupt', 1),
-                Bitfield.ReservedBit(4),
-            ),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('capabilities', 1,
+                 Bitfield.ReservedBit(1),
+                 Bitfield.Bit('warm_reset', 1),
+                 Bitfield.Bit('graceful_reboot', 1),
+                 Bitfield.Bit('diagnostic_interrupt', 1),
+                 Bitfield.ReservedBit(4),),
     )
 
 
@@ -231,18 +229,16 @@ class SetFruActivationPolicyReq(Message):
     __cmdid__ = constants.CMDID_SET_FRU_ACTIVATION_POLICY
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            Bitfield('mask', 1,
-                Bitfield.Bit('activation_locked', 1, default=0),
-                Bitfield.Bit('deactivation_locked', 1, default=0),
-                Bitfield.ReservedBit(6),
-            ),
-            Bitfield('set', 1,
-                Bitfield.Bit('activation_locked', 1, default=0),
-                Bitfield.Bit('deactivation_locked', 1, default=0),
-                Bitfield.ReservedBit(6),
-            ),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        Bitfield('mask', 1,
+                 Bitfield.Bit('activation_locked', 1, default=0),
+                 Bitfield.Bit('deactivation_locked', 1, default=0),
+                 Bitfield.ReservedBit(6),),
+        Bitfield('set', 1,
+                 Bitfield.Bit('activation_locked', 1, default=0),
+                 Bitfield.Bit('deactivation_locked', 1, default=0),
+                 Bitfield.ReservedBit(6),),
     )
 
 
@@ -251,8 +247,8 @@ class SetFruActivationPolicyRsp(Message):
     __cmdid__ = constants.CMDID_SET_FRU_ACTIVATION_POLICY
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -261,8 +257,8 @@ class GetFruActivationPolicyReq(Message):
     __cmdid__ = constants.CMDID_GET_FRU_ACTIVATION_POLICY
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
 
@@ -271,13 +267,12 @@ class GetFruActivationPolicyRsp(Message):
     __cmdid__ = constants.CMDID_GET_FRU_ACTIVATION_POLICY
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('policy', 1,
-                Bitfield.Bit('activation_locked', 1, default=0),
-                Bitfield.Bit('deactivation_locked', 1, default=0),
-                Bitfield.ReservedBit(6),
-            ),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('policy', 1,
+                 Bitfield.Bit('activation_locked', 1, default=0),
+                 Bitfield.Bit('deactivation_locked', 1, default=0),
+                 Bitfield.ReservedBit(6),),
     )
 
 
@@ -286,9 +281,9 @@ class SetFruActivationReq(Message):
     __cmdid__ = constants.CMDID_SET_FRU_ACTIVATION
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('control', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('control', 1),
     )
 
 
@@ -297,8 +292,8 @@ class SetFruActivationRsp(Message):
     __cmdid__ = constants.CMDID_SET_FRU_ACTIVATION
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -307,8 +302,8 @@ class GetDeviceLocatorRecordIdReq(Message):
     __cmdid__ = constants.CMDID_GET_DEVLOC_RECORD_ID
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
 
@@ -317,9 +312,9 @@ class GetDeviceLocatorRecordIdRsp(Message):
     __cmdid__ = constants.CMDID_GET_DEVLOC_RECORD_ID
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('record_id', 2),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('record_id', 2),
     )
 
 
@@ -328,8 +323,8 @@ class GetFruLedPropertiesReq(Message):
     __cmdid__ = constants.CMDID_GET_FRU_LED_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
 
@@ -338,16 +333,15 @@ class GetFruLedPropertiesRsp(Message):
     __cmdid__ = constants.CMDID_GET_FRU_LED_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('general_status_led_properties', 1,
-                Bitfield.Bit('blue_led', 1),
-                Bitfield.Bit('led1', 1),
-                Bitfield.Bit('led2', 1),
-                Bitfield.Bit('led3', 1),
-                Bitfield.ReservedBit(4),
-            ),
-            UnsignedInt('application_specific_led_count', 1),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('general_status_led_properties', 1,
+                 Bitfield.Bit('blue_led', 1),
+                 Bitfield.Bit('led1', 1),
+                 Bitfield.Bit('led2', 1),
+                 Bitfield.Bit('led3', 1),
+                 Bitfield.ReservedBit(4),),
+        UnsignedInt('application_specific_led_count', 1),
     )
 
 
@@ -356,9 +350,9 @@ class GetFruLedColorCapabilitiesReq(Message):
     __cmdid__ = constants.CMDID_GET_FRU_LED_COLOR_CAPABILITIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('led_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('led_id', 1),
     )
 
 
@@ -367,20 +361,19 @@ class GetFruLedColorCapabilitiesRsp(Message):
     __cmdid__ = constants.CMDID_GET_FRU_LED_COLOR_CAPABILITIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('color_capabilities', 1,
-                Bitfield.ReservedBit(1),
-                Bitfield.Bit('blue', 1),
-                Bitfield.Bit('red', 1),
-                Bitfield.Bit('green', 1),
-                Bitfield.Bit('amber', 1),
-                Bitfield.Bit('orange', 1),
-                Bitfield.Bit('white', 1),
-                Bitfield.ReservedBit(1)
-            ),
-            UnsignedIntMask('local_def_color', 1, 0x0f),
-            UnsignedIntMask('override_def_color', 1, 0x0f),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('color_capabilities', 1,
+                 Bitfield.ReservedBit(1),
+                 Bitfield.Bit('blue', 1),
+                 Bitfield.Bit('red', 1),
+                 Bitfield.Bit('green', 1),
+                 Bitfield.Bit('amber', 1),
+                 Bitfield.Bit('orange', 1),
+                 Bitfield.Bit('white', 1),
+                 Bitfield.ReservedBit(1)),
+        UnsignedIntMask('local_def_color', 1, 0x0f),
+        UnsignedIntMask('override_def_color', 1, 0x0f),
     )
 
 
@@ -400,83 +393,87 @@ class GetPowerLevelRsp(Message):
     __cmdid__ = constants.CMDID_GET_POWER_LEVEL
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('properties', 1,
-                Bitfield.Bit('power_level', 5, 0),
-                Bitfield.ReservedBit(2, 0),
-                Bitfield.Bit('dynamic_power_configuration', 1, 0),
-            ),
-            UnsignedInt('delay_to_stable_power', 1),
-            UnsignedInt('power_multiplier', 1),
-            RemainingBytes('power_draw'),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('properties', 1,
+                 Bitfield.Bit('power_level', 5, 0),
+                 Bitfield.ReservedBit(2, 0),
+                 Bitfield.Bit('dynamic_power_configuration', 1, 0),),
+        UnsignedInt('delay_to_stable_power', 1),
+        UnsignedInt('power_multiplier', 1),
+        RemainingBytes('power_draw'),
     )
 
+
 @register_message_class
 class GetFanSpeedPropertiesReq(Message):
     __cmdid__ = constants.CMDID_GET_FAN_SPEED_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
+
 @register_message_class
 class GetFanSpeedPropertiesRsp(Message):
     __cmdid__ = constants.CMDID_GET_FAN_SPEED_PROPERTIES
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('minimum_speed_level', 1),
-            UnsignedInt('maximum_speed_level', 1),
-            UnsignedInt('normal_operation_level', 1),
-            Bitfield('properties', 1,
-                Bitfield.ReservedBit(7, 0),
-                Bitfield.Bit('local_control_supported', 1),
-            ),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('minimum_speed_level', 1),
+        UnsignedInt('maximum_speed_level', 1),
+        UnsignedInt('normal_operation_level', 1),
+        Bitfield('properties', 1,
+                 Bitfield.ReservedBit(7, 0),
+                 Bitfield.Bit('local_control_supported', 1),),
     )
 
+
 @register_message_class
 class SetFanLevelReq(Message):
     __cmdid__ = constants.CMDID_SET_FAN_LEVEL
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('fan_level', 1),
-            UnsignedInt('extra_byte', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('fan_level', 1),
+        UnsignedInt('extra_byte', 1),
     )
 
+
 @register_message_class
 class SetFanLevelRsp(Message):
     __cmdid__ = constants.CMDID_SET_FAN_LEVEL
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
+
 @register_message_class
 class GetFanLevelReq(Message):
     __cmdid__ = constants.CMDID_GET_FAN_LEVEL
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
+
 @register_message_class
 class GetFanLevelRsp(Message):
     __cmdid__ = constants.CMDID_GET_FAN_LEVEL
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('override_fan_level', 1),
-            Optional(
-                RemainingBytes('data'),
-            )
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('override_fan_level', 1),
+        Optional(
+            RemainingBytes('data'),
+        )
     )
 
 
@@ -485,12 +482,12 @@ class SetFruLedStateReq(Message):
     __cmdid__ = constants.CMDID_SET_FRU_LED_STATE
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('led_id', 1),
-            UnsignedInt('led_function', 1),
-            UnsignedInt('on_duration', 1),
-            UnsignedIntMask('color', 1, 0x0f),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('led_id', 1),
+        UnsignedInt('led_function', 1),
+        UnsignedInt('on_duration', 1),
+        UnsignedIntMask('color', 1, 0x0f),
     )
 
 
@@ -499,8 +496,8 @@ class SetFruLedStateRsp(Message):
     __cmdid__ = constants.CMDID_SET_FRU_LED_STATE
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -510,9 +507,9 @@ class GetFruLedStateReq(Message):
     __netfn__ = constants.NETFN_GROUP_EXTENSION
 
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('led_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('led_id', 1),
     )
 
 
@@ -529,25 +526,24 @@ class GetFruLedStateRsp(Message):
         return obj.led_states.lamp_test_en == 1
 
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('led_states', 1,
-                Bitfield.Bit('local_avail', 1),
-                Bitfield.Bit('override_en', 1),
-                Bitfield.Bit('lamp_test_en', 1),
-                Bitfield.ReservedBit(5)
-            ),
-            UnsignedInt('local_function', 1),
-            UnsignedInt('local_on_duration', 1),
-            UnsignedIntMask('local_color', 1, 0x0f),
-            Conditional(_cond_override,
-                UnsignedInt('override_function', 1)),
-            Conditional(_cond_override,
-                UnsignedInt('override_on_duration', 1)),
-            Conditional(_cond_override,
-                UnsignedIntMask('override_color', 1, 0x0f)),
-            Conditional(_cond_lamp_test,
-                UnsignedIntMask('lamp_test_duration', 1, 0x7f)),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('led_states', 1,
+                 Bitfield.Bit('local_avail', 1),
+                 Bitfield.Bit('override_en', 1),
+                 Bitfield.Bit('lamp_test_en', 1),
+                 Bitfield.ReservedBit(5)),
+        UnsignedInt('local_function', 1),
+        UnsignedInt('local_on_duration', 1),
+        UnsignedIntMask('local_color', 1, 0x0f),
+        Conditional(_cond_override,
+                    UnsignedInt('override_function', 1)),
+        Conditional(_cond_override,
+                    UnsignedInt('override_on_duration', 1)),
+        Conditional(_cond_override,
+                    UnsignedIntMask('override_color', 1, 0x0f)),
+        Conditional(_cond_lamp_test,
+                    UnsignedIntMask('lamp_test_duration', 1, 0x7f)),
     )
 
 
@@ -556,20 +552,19 @@ class SetPortStateReq(Message):
     __cmdid__ = constants.CMDID_SET_PORT_STATE
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            Bitfield('link_info', 4,
-                Bitfield.Bit('channel', 6),
-                Bitfield.Bit('interface', 2),
-                Bitfield.Bit('port_0', 1),
-                Bitfield.Bit('port_1', 1),
-                Bitfield.Bit('port_2', 1),
-                Bitfield.Bit('port_3', 1),
-                Bitfield.Bit('type', 4),
-                Bitfield.Bit('sig_class', 4, 0),
-                Bitfield.Bit('type_extension', 4),
-                Bitfield.Bit('grouping_id', 8, 0),
-            ),
-            UnsignedInt('state', 1),
+        PicmgIdentifier(),
+        Bitfield('link_info', 4,
+                 Bitfield.Bit('channel', 6),
+                 Bitfield.Bit('interface', 2),
+                 Bitfield.Bit('port_0', 1),
+                 Bitfield.Bit('port_1', 1),
+                 Bitfield.Bit('port_2', 1),
+                 Bitfield.Bit('port_3', 1),
+                 Bitfield.Bit('type', 4),
+                 Bitfield.Bit('sig_class', 4, 0),
+                 Bitfield.Bit('type_extension', 4),
+                 Bitfield.Bit('grouping_id', 8, 0),),
+        UnsignedInt('state', 1),
     )
 
 
@@ -578,8 +573,8 @@ class SetPortStateRsp(Message):
     __cmdid__ = constants.CMDID_SET_PORT_STATE
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -588,11 +583,10 @@ class GetPortStateReq(Message):
     __cmdid__ = constants.CMDID_GET_PORT_STATE
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            Bitfield('channel', 1,
-                Bitfield.Bit('number', 6),
-                Bitfield.Bit('interface', 2),
-            ),
+        PicmgIdentifier(),
+        Bitfield('channel', 1,
+                 Bitfield.Bit('number', 6),
+                 Bitfield.Bit('interface', 2),),
     )
 
 
@@ -601,9 +595,9 @@ class GetPortStateRsp(Message):
     __cmdid__ = constants.CMDID_GET_PORT_STATE
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            RemainingBytes('data'),
+        CompletionCode(),
+        PicmgIdentifier(),
+        RemainingBytes('data'),
     )
 
 
@@ -612,15 +606,13 @@ class SetSignalingClassReq(Message):
     __cmdid__ = constants.CMDID_SET_CHANNEL_SIGNALING_CLASS
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            Bitfield('channel_info', 1,
-                Bitfield.Bit('channel_number', 6, 0),
-                Bitfield.Bit('interface', 2, 0),
-            ),
-            Bitfield('channel_signaling', 1,
-                Bitfield.Bit('class_capability', 4, 0),
-                Bitfield.ReservedBit(4)
-            ),
+        PicmgIdentifier(),
+        Bitfield('channel_info', 1,
+                 Bitfield.Bit('channel_number', 6, 0),
+                 Bitfield.Bit('interface', 2, 0),),
+        Bitfield('channel_signaling', 1,
+                 Bitfield.Bit('class_capability', 4, 0),
+                 Bitfield.ReservedBit(4)),
     )
 
 
@@ -629,8 +621,8 @@ class SetSignalingClassRsp(Message):
     __cmdid__ = constants.CMDID_SET_CHANNEL_SIGNALING_CLASS
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
+        CompletionCode(),
+        PicmgIdentifier(),
     )
 
 
@@ -639,11 +631,10 @@ class GetSignalingClassReq(Message):
     __cmdid__ = constants.CMDID_GET_CHANNEL_SIGNALING_CLASS
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            Bitfield('channel_info', 1,
-                Bitfield.Bit('channel_number', 6, 0),
-                Bitfield.Bit('interface', 2, 0),
-            ),
+        PicmgIdentifier(),
+        Bitfield('channel_info', 1,
+                 Bitfield.Bit('channel_number', 6, 0),
+                 Bitfield.Bit('interface', 2, 0),),
     )
 
 
@@ -652,16 +643,14 @@ class GetSignalingClassRsp(Message):
     __cmdid__ = constants.CMDID_GET_CHANNEL_SIGNALING_CLASS
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('channel_info', 1,
-                Bitfield.Bit('channel_number', 6, 0),
-                Bitfield.Bit('interface', 2, 0),
-            ),
-            Bitfield('channel_signaling', 1,
-                Bitfield.Bit('class_capability', 4, 0),
-                Bitfield.ReservedBit(4)
-            ),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('channel_info', 1,
+                 Bitfield.Bit('channel_number', 6, 0),
+                 Bitfield.Bit('interface', 2, 0),),
+        Bitfield('channel_signaling', 1,
+                 Bitfield.Bit('class_capability', 4, 0),
+                 Bitfield.ReservedBit(4)),
     )
 
 
@@ -670,14 +659,13 @@ class GetLocationInformationReq(Message):
     __cmdid__ = constants.CMDID_GET_LOCATION_INFO
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            Bitfield('info', 1,
-                Bitfield.Bit('carrier_number', 5, 0),
-                Bitfield.ReservedBit(1),
-                Bitfield.Bit('mcs', 2, 0),
-            ),
-            UnsignedInt('site_number', 1),
-            UnsignedInt('site_type', 1),
+        PicmgIdentifier(),
+        Bitfield('info', 1,
+                 Bitfield.Bit('carrier_number', 5, 0),
+                 Bitfield.ReservedBit(1),
+                 Bitfield.Bit('mcs', 2, 0),),
+        UnsignedInt('site_number', 1),
+        UnsignedInt('site_type', 1),
     )
 
 
@@ -686,18 +674,17 @@ class GetLocationInformationRsp(Message):
     __cmdid__ = constants.CMDID_GET_LOCATION_INFO
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('slot_number', 1),
-            UnsignedInt('tier_number', 1),
-            Bitfield('info', 1,
-                Bitfield.ReservedBit(5),
-                Bitfield.Bit('carrier_orientation', 1, 0),
-                Bitfield.Bit('tier_number', 1, 0),
-                Bitfield.Bit('slot_number', 1, 0),
-            ),
-            UnsignedInt('origin_x', 2),
-            UnsignedInt('origin_y', 2),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('slot_number', 1),
+        UnsignedInt('tier_number', 1),
+        Bitfield('info', 1,
+                 Bitfield.ReservedBit(5),
+                 Bitfield.Bit('carrier_orientation', 1, 0),
+                 Bitfield.Bit('tier_number', 1, 0),
+                 Bitfield.Bit('slot_number', 1, 0),),
+        UnsignedInt('origin_x', 2),
+        UnsignedInt('origin_y', 2),
     )
 
 
@@ -706,9 +693,9 @@ class GetPowerChannelStatusReq(Message):
     __cmdid__ = constants.CMDID_GET_POWER_CHANNEL_STATUS
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('starting_power_channel_number', 1),
-            UnsignedInt('power_channel_count', 1),
+        PicmgIdentifier(),
+        UnsignedInt('starting_power_channel_number', 1),
+        UnsignedInt('power_channel_count', 1),
     )
 
 
@@ -717,17 +704,16 @@ class GetPowerChannelStatusRsp(Message):
     __cmdid__ = constants.CMDID_GET_POWER_CHANNEL_STATUS
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            UnsignedInt('max_power_channel_number', 1),
-            Bitfield('global_status', 1,
-                Bitfield.Bit('role', 1, 0),
-                Bitfield.Bit('management_power_good', 1, 0),
-                Bitfield.Bit('payload_power_good', 1, 0),
-                Bitfield.Bit('unidentified_fault', 1, 0),
-                Bitfield.ReservedBit(4),
-            ),
-            RemainingBytes('data'),
+        CompletionCode(),
+        PicmgIdentifier(),
+        UnsignedInt('max_power_channel_number', 1),
+        Bitfield('global_status', 1,
+                 Bitfield.Bit('role', 1, 0),
+                 Bitfield.Bit('management_power_good', 1, 0),
+                 Bitfield.Bit('payload_power_good', 1, 0),
+                 Bitfield.Bit('unidentified_fault', 1, 0),
+                 Bitfield.ReservedBit(4),),
+        RemainingBytes('data'),
     )
 
 
@@ -736,8 +722,8 @@ class GetTelcoAlarmCapabilityReq(Message):
     __cmdid__ = constants.CMDID_GET_TELCO_ALARM_CAPABILITY
     __netfn__ = constants.NETFN_GROUP_EXTENSION
     __fields__ = (
-            PicmgIdentifier(),
-            UnsignedInt('fru_id', 1),
+        PicmgIdentifier(),
+        UnsignedInt('fru_id', 1),
     )
 
 
@@ -746,16 +732,15 @@ class GetTelcoAlarmCapabilityRsp(Message):
     __cmdid__ = constants.CMDID_GET_TELCO_ALARM_CAPABILITY
     __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
     __fields__ = (
-            CompletionCode(),
-            PicmgIdentifier(),
-            Bitfield('alarm_capabilities', 1,
-                Bitfield.Bit('critical_alarm', 1, 0),
-                Bitfield.Bit('major_alarm', 1, 0),
-                Bitfield.Bit('minor_alarm', 1, 0),
-                Bitfield.Bit('power_alarm', 1, 0),
-                Bitfield.Bit('test_alarm', 1, 0),
-                Bitfield.Bit('autonomous_alarm_cutoff', 1, 0),
-                Bitfield.Bit('autonomous_minor_reset', 1, 0),
-                Bitfield.Bit('autonomous_majorreset', 1, 0),
-            ),
+        CompletionCode(),
+        PicmgIdentifier(),
+        Bitfield('alarm_capabilities', 1,
+                 Bitfield.Bit('critical_alarm', 1, 0),
+                 Bitfield.Bit('major_alarm', 1, 0),
+                 Bitfield.Bit('minor_alarm', 1, 0),
+                 Bitfield.Bit('power_alarm', 1, 0),
+                 Bitfield.Bit('test_alarm', 1, 0),
+                 Bitfield.Bit('autonomous_alarm_cutoff', 1, 0),
+                 Bitfield.Bit('autonomous_minor_reset', 1, 0),
+                 Bitfield.Bit('autonomous_majorreset', 1, 0),),
     )
